// $Id: CvsCheckOutDialog.cpp,v 1.18 2014/09/26 08:06:18 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CvsCheckOutDialog.h"
#include "CvsCheckOutDialog.moc"

#include <QCheckBox>
#include <QLabel>
#include <QLayout>

//________________________________________________________________
CvsCheckOutDialog::CvsCheckOutDialog( QWidget* parent ):
CustomDialog( parent ),
state_( false )
{
    Debug::Throw( "CvsCheckOutDialog::CvsCheckOutDialog.\n" );
    QVBoxLayout* layout( new QVBoxLayout() );
    layout->setMargin(0);
    layout->setSpacing(5);
    mainLayout().addLayout( layout );

    layout->addWidget( new QLabel( tr( "CVS Root directory:" ), this ) );
    layout->addWidget( rootEditor_ = new AnimatedLineEditor( this ) );

    layout->addWidget( new QLabel( tr( "Module names (use \",\" to separate modules):" ), this ) );
    layout->addWidget( moduleEditor_ = new AnimatedLineEditor( this ) );

    localNameCheckBox_ = new QCheckBox( tr( "Use a different name for the local directory" ), this );
    layout->addWidget( localNameCheckBox_ );
    layout->addWidget( localNameEditor_ = new AnimatedLineEditor( this ) );
    localNameEditor_->setEnabled( localNameCheckBox_->isChecked() );

    connect( localNameCheckBox_, SIGNAL(toggled(bool)), localNameEditor_, SLOT(setEnabled(bool)) );
    connect( moduleEditor_, SIGNAL(textChanged(QString)), SLOT(_checkModules(QString)) );

    adjustSize();

    return;
}

//______________________________________________________________
QList<QString> CvsCheckOutDialog::modules( void ) const
{

    Debug::Throw( "CvsCheckOutDialog::modules.\n" );
    QStringList modules_list( moduleEditor_->text().split( ",", QString::SkipEmptyParts ) );
    QList<QString> out;
    for( QStringList::iterator iter = modules_list.begin(); iter != modules_list.end(); ++iter )
    { out << iter->trimmed(); }
    return out;

}


//________________________________________________________________
void CvsCheckOutDialog::_checkModules( const QString& value )
{

    if( value.indexOf( "," ) >= 0 )
    {

        state_ = localNameCheckBox_->isChecked();
        localNameCheckBox_->setChecked( false );
        localNameCheckBox_->setEnabled( false );

    } else if( !localNameCheckBox_->isEnabled() ) {

        localNameCheckBox_->setEnabled( true );
        localNameCheckBox_->setChecked( state_ );

    }

}
