// $Id: CvsCommandDialog.cpp,v 1.18 2014/09/26 08:06:18 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CvsCommandDialog.h"
#include "CvsCommandDialog.moc"

#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "TreeView.h"

#include <QHeaderView>
#include <QLayout>
#include <QShortcut>

//____________________________________________________________
CvsCommandDialog::CvsCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "CvsCommandDialog::CvsCommandDialog.\n" );
    setWindowTitle( tr( "Commands - Cvswatch" ) );
    setOptionName( "CVS_COMMANDS_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    // main widget
    list_ = new TreeView( this );
    list_->setModel( &model_ );
    list_->setSortingEnabled( true );
    list_->setOptionName( "CVS_COMMAND_LIST" );
    list_->header()->hide();
    mainLayout().addWidget( list_ );

    // context menu
    QMenu* menu( new ContextMenu( list_ ) );
    menu->addMenu( new ColumnSortingMenu( menu, list_ ) );
    menu->addMenu( new ColumnSelectionMenu( menu, list_ ) );

    // ok button
    connect( &okButton(), SIGNAL(pressed()), SLOT(close()) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT(close()) );

}

//_____________________________________________________________
void CvsCommandDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "CvsCommandDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
