#ifndef CvsCommandModel_h
#define CvsCommandModel_h

// $Id: CvsCommandModel.h,v 1.18 2014/09/12 08:43:11 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "CvsCommand.h"

#include <QHash>

//! Job model. Stores job information for display in lists
class CvsCommandModel : public ListModel<CvsCommand>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    CvsCommandModel( QObject* = 0 );

    //! destructor
    virtual ~CvsCommandModel()
    {}

    //! column type enumeration
    enum ColumnType
    {
        Id,
        Name,
        Path,
        nColumns
    };

    //!@name methods reimplemented from base class
    //@{

    //! data
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    public Q_SLOTS:

    //! add file
    virtual void add( const CvsCommand& );

    //! remove
    virtual void remove( const CvsCommand& );

    private Q_SLOTS:

    //! update configuration
    void _updateConfiguration( void );

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
    {}

    private:

    //! icon cache
    using IconCache = QHash<CvsCommand::Type, QIcon>;

    //! install pixmaps
    void _installIcons( void ) const;

    //! type icon cache for local modifications
    static IconCache& _icons( void );

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
