#ifndef DefaultOptions_h
#define DefaultOptions_h

// $Id: DefaultOptions.h,v 1.40 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CvsCommandModel.h"
#include "File.h"
#include "FileInfoModel.h"
#include "FileSelectionFrame.h"
#include "LogDialog.h"
#include "XmlOptions.h"
#include "Util.h"

//_____________________________________________________
//! default options installer
void installDefaultOptions( void )
{

    // set options default values
    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().set<int>( "DB_SIZE", 30 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_HEIGHT", 500 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_WIDTH", 700 );

    // customize pixmap path
    XmlOptions::get().keep( "PIXMAP_PATH" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/128x128" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/48x48" );

    XmlOptions::get().set<bool>( "SHOW_NAVIGATOR", true );
    XmlOptions::get().set<bool>( "USE_TRUNCATION", true );

    XmlOptions::get().set<bool>( "SHOW_COMMAND_LIST", false );
    XmlOptions::get().set<bool>( "SHOW_LOG", false );
    XmlOptions::get().set<bool>( "SHOW_TOOLTIPS", false );
    XmlOptions::get().set<bool>( "SHOW_HIDDEN_FILES", false );

    // verbosity
    XmlOptions::get().set<int>( "VERBOSITY", CvsInterface::VerbosityLow );

    // toolbars
    XmlOptions::get().set<bool>( "NAVIGATION_TOOLBAR", true );
    XmlOptions::get().set<bool>( "CVS_REMOTE_TOOLBAR", true );
    XmlOptions::get().set<bool>( "CVS_LOCAL_TOOLBAR", true );

    // mask
    XmlOptions::get().set<unsigned int>( "FILE_LIST_MASK", (1<<FileInfoModel::Filename) | (1<<FileInfoModel::Size) );
    XmlOptions::get().set<unsigned int>( "CVS_COMMAND_LIST_MASK", (1<<CvsCommandModel::Name) | (1<<CvsCommandModel::Path) );

    // view mode
    XmlOptions::get().set<unsigned int>( "VIEW_MODE", FileSelectionFrame::Icons );

    // cache
    XmlOptions::get().set<bool>( "LIMIT_REVISION_CACHE", false );
    XmlOptions::get().set<int>( "REVISION_CACHE_SIZE", 5 );

    XmlOptions::get().set<bool>( "LIMIT_FILEINFO_CACHE", false );
    XmlOptions::get().set<int>( "FILEINFO_CACHE_SIZE", 5 );

    // pixmap size
    XmlOptions::get().set<int>( "ICON_VIEW_PIXMAP_SIZE", 48 );

    // cvs root
    XmlOptions::get().set( "DEFAULT_CVSROOT", Util::env( "CVSROOT","" ) );

    // non recordable options
    XmlOptions::get().set( "CACHE_FILE", Option( File( ".cvswatchrc" ).addPath( Util::home() ), Option::None ) );
    XmlOptions::get().set( "RC_FILE", Option( File(".cvswatchrc").addPath( Util::home() ), Option::None ) );
    XmlOptions::get().setAutoDefault( false );

};

#endif
