// $Id: FileInfoCacheDialog.cpp,v 1.12 2013/04/29 18:27:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Application.h"
#include "FileInfoCacheDialog.h"
#include "Singleton.h"
#include "TreeView.h"

#include <QPushButton>
#include <QLabel>
#include <QLayout>

//__________________________________________________________________________
FileInfoCacheDialog::FileInfoCacheDialog( QWidget* parent ):
CustomDialog( parent, CloseButton )
{

    Debug::Throw( "FileInfoCacheDialog::FileInfoCacheDialog.\n" );
    setOptionName( "REVISION_CACHE_DIALOG" );

    // create list
    mainLayout().addWidget( list_ = new TreeView( this ) );
    _list().setModel( &model_ );
    _list().setRootIsDecorated( true );
    _list().setOptionName( "REVISION_CACHE_LIST" );

}

//__________________________________________________________________________
void FileInfoCacheDialog::setCache( const FileInfoCache& cache )
{

    Debug::Throw( "FileInfoCacheDialog::setCache.\n" );

    // busy
    Singleton::get().application<Application>()->busy();
    FileInfoModel::List files;
    foreach( FileInfo fileInfo, cache )
    {
        fileInfo.update();
        files << fileInfo;
    }
    Singleton::get().application<Application>()->idle();

    model_.set( files );
    _list().resizeColumns();

}
