// $Id: FileInfoModel.cpp,v 1.40 2014/02/10 20:50:48 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileInfoModel.h"

#include "FileIconProvider.h"
#include "Singleton.h"
#include "TimeStamp.h"
#include "XmlOptions.h"

#include <QIcon>
#include <QUrl>
#include <QMimeData>

//_______________________________________________________________
FileInfoModel::FileInfoModel( QObject* parent ):
    BaseFileInfoModel<FileInfo>( parent ),
    Counter( "FileInfoModel" ),
    iconProvider_( 0x0 )
{ Debug::Throw( "FileInfoModel::FileInfoModel.\n" ); }

//__________________________________________________________________
Qt::ItemFlags FileInfoModel::flags(const QModelIndex &index) const
{

    Qt::ItemFlags flags( BaseFileInfoModel<FileInfo>::flags( index ) );
    if( index.isValid() && contains( index ) )
    {

        // retrieve associated file info
        const FileInfo& fileInfo( get()[index.row()] );
        if( fileInfo.isNavigator() ) flags &= ~Qt::ItemIsSelectable;
        else {

            flags |= Qt::ItemIsDragEnabled;

        }

    }

    return flags;

}
//______________________________________________________________________
QMimeData* FileInfoModel::mimeData(const QModelIndexList &indexes) const
{

    QOrderedSet<QString> filenames;
    QOrderedSet<FileInfo> fileInfoList;

    foreach( const QModelIndex& index, indexes )
    {

        if( index.isValid() )
        {
            FileInfo info( get(index) );
            if( info.isNavigator() ) continue;

            fileInfoList.insert( info );
            filenames.insert( info.file() );
        }

    }

    if( filenames.empty() ) return 0;
    else {

        QMimeData *mimeData = new QMimeData();

        // fill text and url data
        QList<QUrl> urlList;
        QString fullText;
        QTextStream buffer( &fullText );
        foreach( const QString& filename, filenames )
        {
            QString url;
            QTextStream( &url ) << "file://" << filename;
            buffer << url << endl;
            urlList << url;
        }

        mimeData->setText( fullText );
        mimeData->setUrls( urlList );

        // fill Drag data. Use XML
        QDomDocument document;
        QDomElement top = document.appendChild( document.createElement( Xml::FileInfoList ) ).toElement();
        foreach( const FileInfo& fileInfo, fileInfoList )
        {

            if( fileInfo.file().isEmpty() ) continue;
            top.appendChild( fileInfo.domElement( document ) );

        }

        mimeData->setData( BaseFileInfo::MimeType, document.toByteArray() );
        return mimeData;

    }

}

//____________________________________________________________
QIcon FileInfoModel::_icon( const QModelIndex& index ) const
{ return iconProvider_ ? iconProvider_->icon( get( index ) ):QIcon(); }
