// $Id: RevisionCacheDialog.cpp,v 1.11 2013/04/29 18:27:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/
/*!
\file RevisionCacheDialog.cpp
\brief displays all run-time options
\author Hugo Pereira
\version $Revision: 1.11 $
\date $Date: 2013/04/29 18:27:10 $
*/

#include "RevisionCacheDialog.h"
#include "TreeView.h"

#include <QPushButton>
#include <QLabel>
#include <QLayout>

//__________________________________________________________________________
RevisionCacheDialog::RevisionCacheDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "RevisionCacheDialog::RevisionCacheDialog.\n" );
    setOptionName( "REVISION_CACHE_DIALOG" );

    // create list
    mainLayout().addWidget( list_ = new TreeView( this ) );
    _list().setModel( &model_ );
    _list().setRootIsDecorated( true );
    _list().setOptionName( "REVISION_CACHE_LIST" );

}

//__________________________________________________________________________
void RevisionCacheDialog::setCache( const RevisionCache& cache )
{

    Debug::Throw( "RevisionCacheDialog::setCache.\n" );

    RevisionCacheModel::List revisions;
    for( RevisionCache::const_iterator iter = cache.begin(); iter != cache.end(); ++iter )
    {
        for( Revision::List::const_iterator revIter = iter.value().begin(); revIter != iter.value().end(); ++revIter )
        { revisions << RevisionPair( iter.key(), *revIter ); }
    }

    model_.add( revisions );
    _list().resizeColumns();

}
