// $Id: RevisionCacheModel.cpp,v 1.12 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "RevisionCacheModel.h"
#include "RevisionCacheModel.moc"
#include "Singleton.h"
#include "XmlOptions.h"

//_______________________________________________
const QString RevisionCacheModel::columnTitles_[ RevisionCacheModel::nColumns ] =
{
    tr( "File" ),
    tr( "Path" ),
    tr( "Revision" ),
    tr( "Date" ),
    tr( "Author" )
};

//_______________________________________________________________
RevisionCacheModel::RevisionCacheModel( QObject* parent ):
    TreeModel<RevisionPair>( parent ),
    Counter( "RevisionCacheModel" )
{ Debug::Throw( "RevisionCacheModel::RevisionCacheModel.\n" ); }


//__________________________________________________________________
QVariant RevisionCacheModel::data( const QModelIndex& index, int role ) const
{

    // check index, role and column
    if( !index.isValid() ) return QVariant();
    if( role == Qt::DisplayRole )
    {

        // retrieve associated command
        const RevisionPair& revision( _find( index.internalId() ).get() );

        switch( index.column() )
        {
            case Filename: return revision.first.localName();
            case Path: return revision.first.path();
            case Revision: return revision.second.name();
            case Date: return revision.second.timeStamp().toString();
            case Author: return revision.second.author();
            default: return QVariant();
        }

    }

    return QVariant();

}

//__________________________________________________________________
QVariant RevisionCacheModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < int(nColumns) )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//___________________________________________________________
bool RevisionCacheModel::SortFTor::operator() ( RevisionPair first, RevisionPair second ) const
{

    if( order_ == Qt::DescendingOrder ) std::swap( first, second );

    switch( type_ )
    {

        default:
        case Filename:
        return first.first.localName() < second.first.localName();
        break;

        case Path:
        return first.first.path() < second.first.path();
        break;

        case Revision:
        return first.second.name() < second.second.name();
        break;

        case Date:
        return first.second.timeStamp() < second.second.timeStamp();
        break;

        case Author:
        return first.second.author() < second.second.author();
        break;

    }

    return true;

}
